==> 0.2.1.tar.gz: lib/pages/scan/ScanCode.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_easyloading/flutter_easyloading.dart';
import 'package:witsystem_core/error/NetError.dart';
import 'package:witsystem_core/error/entity/WitsystemError.dart';
import 'package:witsystem_core/net/WitsystemNet.dart';
import 'package:witsystem_core/pages/code/Scan.dart';
import 'package:witsystem_core/permission/WitsPermission.dart';
import 'package:witsystem_device_manage/generated/l10n.dart';
import 'package:barcode_scan2/barcode_scan2.dart';
import 'package:witsystem_device_manage/pages/home/add/AddDevice.dart';
import 'package:witsystem_device_plugin/device/DeviceManage.dart';
import 'package:witsystem_device_plugin/device/Unlock.dart';

///扫描处理页面

class ScanCodeWidget extends StatefulWidget {
  const ScanCodeWidget({Key? key}) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _ScanCodeState();
  }
}

class _ScanCodeState extends State<ScanCodeWidget> {
  @override
  void initState() {
    super.initState();
    scanInfo();
  }

  scanInfo() async {
    try {
      ScanResult result = await Scan(
              flashOff: S.current.device_offLight,
              flashOn: S.current.device_onLight)
          .start();
      debugPrint("扫描获得的数据${result.rawContent}");
      if (result.rawContent == "") {
        Navigator.of(context).pop();
        return;
      }
      if (!result.rawContent.contains("action")) {
        //EasyLoading.showToast("无法识别");
        Navigator.of(context).pop({"content": result.rawContent});
        return;
      }
      var queryParameters = Uri.parse(result.rawContent).queryParameters;

      if (queryParameters["deviceId"] == null) {
        Navigator.of(context).pop({"content": result.rawContent});
        return;
      }

      debugPrint("扫描获得的queryParameters数据${queryParameters}");

      switch (queryParameters["action"]) {
        case 'scanQrCoderSendKey':
          await _scanGetDevice(queryParameters["qrCodeInfo"]!);
          break;
        case 'unlock':
          await _unlock(queryParameters["deviceId"]!);
          break;
        case 'addDevice':
          Navigator.of(context).pushReplacement(MaterialPageRoute(builder: (context) {
            return const AddDeviceWidget();
          }));
          break;
        case 'unlockOrAddDevice':
          var device =
              await DeviceManage().device(queryParameters["deviceId"]!);
          if (device == null) {
            Navigator.of(context).pushReplacement(MaterialPageRoute(builder: (context) {
              return const AddDeviceWidget();
            }));
          } else {
            await _unlock(queryParameters["deviceId"]!);
          }
          break;

        default:
          Navigator.of(context).pop({"content": result.rawContent});
          break;
      }
    } catch (e) {
      Navigator.of(context).pop();
    }
  }

  ///开门
  _unlock(String deviceId) async {
    try {
      if (!await WitsPermission.blePermission()) return;
      EasyLoading.show(
          status: S.of(context).device_openLoading,
          maskType: EasyLoadingMaskType.clear);
      await Unlock.instance.bleUnlock(deviceId);
      EasyLoading.showSuccess(S.of(context).device_openSuccess);
    } on PlatformException catch (e) {
      EasyLoading.showError(
          S.of(context).device_openFail(e.message.toString()));
    }
    Navigator.of(context).pop(context);
  }

  ///扫描获得设备权限
  _scanGetDevice(String qrCodeInfo) async {
    try {
      EasyLoading.show(
          status: S.of(context).device_loading,
          maskType: EasyLoadingMaskType.clear);
      WitsystemError witsystemError = await WitsystemNet.authPost(
          "/user/devices/submit_share_qr_code_info",
          {"qrCodeInfo": qrCodeInfo});
      debugPrint("返回的信息${witsystemError.error}");
      if(witsystemError.code==NetError.succesCode){
        DeviceManage().refurbishAllDevice();
      }
      EasyLoading.showSuccess(witsystemError.error);
    } catch (e) {
      EasyLoading.showError(S.of(context).device_fail(""));
    }
    Navigator.of(context).pop(context);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: Text(S.current.device_scanningCode)),
      body: Container(),
    );
  }
}

==> 0.2.8.tar.gz: lib/pages/scan/ScanCode.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_easyloading/flutter_easyloading.dart';
import 'package:witsystem_core/error/NetError.dart';
import 'package:witsystem_core/error/entity/WitsystemError.dart';
import 'package:witsystem_core/net/WitsystemNet.dart';
import 'package:witsystem_core/pages/code/Scan.dart';
import 'package:witsystem_core/pages/code/WitsystemScanResult.dart';
import 'package:witsystem_core/permission/WitsPermission.dart';
import 'package:witsystem_device_manage/generated/l10n.dart';
import 'package:witsystem_device_manage/pages/home/add/AddDevice.dart';
import 'package:witsystem_device_plugin/device/DeviceManage.dart';
import 'package:witsystem_device_plugin/device/Unlock.dart';

///扫描处理页面

class ScanCodeWidget extends StatefulWidget {
  const ScanCodeWidget({Key? key}) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _ScanCodeState();
  }
}

class _ScanCodeState extends State<ScanCodeWidget> {
  @override
  void initState() {
    super.initState();
    scanInfo();
  }
  //barcode_scan2
  scanInfo() async {
    try {
      WitsystemScanResult result = await Scan(
              flashOff: S.current.device_offLight,
              flashOn: S.current.device_onLight)
          .start();
      debugPrint("扫描获得的数据${result.rawContent}");
      if (result.rawContent == "") {
        Navigator.of(context).pop();
        return;
      }
      if (!result.rawContent.contains("action")) {
        //EasyLoading.showToast("无法识别");
        Navigator.of(context).pop({"content": result.rawContent});
        return;
      }
      var queryParameters = Uri.parse(result.rawContent).queryParameters;

      if (queryParameters["deviceId"] == null) {
        Navigator.of(context).pop({"content": result.rawContent});
        return;
      }

      debugPrint("扫描获得的queryParameters数据${queryParameters}");

      switch (queryParameters["action"]) {
        case 'scanQrCoderSendKey':
          await _scanGetDevice(queryParameters["qrCodeInfo"]!);
          break;
        case 'unlock':
          await _unlock(queryParameters["deviceId"]!);
          break;
        case 'addDevice':
          Navigator.of(context).pushReplacement(MaterialPageRoute(builder: (context) {
            return const AddDeviceWidget();
          }));
          break;
        case 'unlockOrAddDevice':
          var device =
              await DeviceManage().device(queryParameters["deviceId"]!);
          if (device == null) {
            Navigator.of(context).pushReplacement(MaterialPageRoute(builder: (context) {
              return const AddDeviceWidget();
            }));
          } else {
            await _unlock(queryParameters["deviceId"]!);
          }
          break;

        default:
          Navigator.of(context).pop({"content": result.rawContent});
          break;
      }
    } catch (e) {
      Navigator.of(context).pop();
    }
  }

  ///开门
  _unlock(String deviceId) async {
    try {
      if (!await WitsPermission.blePermission()) return;
      EasyLoading.show(
          status: S.of(context).device_openLoading,
          maskType: EasyLoadingMaskType.clear);
      await Unlock.instance.bleUnlock(deviceId);
      EasyLoading.showSuccess(S.of(context).device_openSuccess);
    } on PlatformException catch (e) {
      EasyLoading.showError(
          S.of(context).device_openFail(e.message.toString()));
    }
    Navigator.of(context).pop(context);
  }

  ///扫描获得设备权限
  _scanGetDevice(String qrCodeInfo) async {
    try {
      EasyLoading.show(
          status: S.of(context).device_loading,
          maskType: EasyLoadingMaskType.clear);
      WitsystemError witsystemError = await WitsystemNet.authPost(
          "/user/devices/submit_share_qr_code_info",
          {"qrCodeInfo": qrCodeInfo});
      debugPrint("返回的信息${witsystemError.error}");
      if(witsystemError.code==NetError.succesCode){
        DeviceManage().refurbishAllDevice();
      }
      EasyLoading.showSuccess(witsystemError.error);
    } catch (e) {
      EasyLoading.showError(S.of(context).device_fail(""));
    }
    Navigator.of(context).pop(context);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: Text(S.current.device_scanningCode)),
      body: Container(),
    );
  }
}
